Description Usage Arguments Format Details Value Examples
The mdi_get_data() function currently retrieves data from FRED.
The 'default' series includes a range of indicators from Fundamental to Behavioral and Catalyst categories. The sub-categories and their respective tickers and descriptions are described in the Details section. Users can specify their own character of symbols TODO - add descriptions next to ticker
1 |
symbols |
Character vector of symbol names to download. Default: NULL, which will return all the symbols described in @details. |
An object of class environment of length 1.
The sub-categories and their respective tickers and descriptions are described below.
| FUNDAMENTAL | |
| Economic Trend: | |
| OECDLOLITOAASTSAM | TODO: add description |
| ICSA | |
| INDPRO | |
| T10Y2Y | |
| BAA10Y | |
| --- | --- |
| Liquidity: | |
| NFCI | |
| --- | --- |
| Velocity: | |
| M2V | |
| TOTCI | |
| M0263AUSM500NNBR | |
| M0264AUSM500NNBR | |
| BOGZ1FA895050005Q | |
| --- | --- |
| --- | --- |
| BEHAVIORAL | |
| Confirmation Bias: Surveys | |
| UMCSENT | |
| CSUSHPISA | |
| SPCS20RSA | |
| --- | --- |
| Representative Bias: Options Market | |
| VIXCLS | |
| VXVCLS | |
| EVZCLS | |
| THREEFYTP10 - | |
| --- | --- |
| Cognitive Dissonance: | |
| EMVOVERALLEMV | |
| --- | --- |
| Loss Aversion: | |
| --- | --- |
| Anchoring Bias: | |
| --- | --- |
| Framing Bias: | |
| --- | --- |
| Overconfidence: | |
| --- | --- |
| --- | --- |
| CATALYST | |
| Earnings Surprise: | |
| --- | --- |
| Economic Surprise: | |
| CFNAIMA3 | |
| STLENI | |
| STLFSI2 | |
| --- | --- |
| Geopolitics: | |
| WLEMUINDXD | |
Applicable time series data from FRED, stored as xts thanks to the internal getSymbols.FRED function. Data to be stored in a new environment called econ_data.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.